pub struct ApiContractVersion { /* private fields */ }Implementations
Sourceimpl ApiContractVersion
impl ApiContractVersion
pub const V1_7: Self
pub const V1_8: Self
pub const CURRENT: Self = Self::V1_8
pub const MINIMUM_SUPPORTED: Self = Self::V1_7
pub const fn as_str(self) -> &'static str
Sourcepub fn resolve_observed(value: &str) -> Result<Self, ApiVersionParseError>
pub fn resolve_observed(value: &str) -> Result<Self, ApiVersionParseError>
Resolve an observed response contract to the newest contract this SDK can safely request. Newer minor versions remain compatible through Keygen’s version pinning, while a different major version does not.